+++
title = "Source block, followed by a quote block containing another source block"
tags = ["quotes"]
draft = false
+++

Some text.

```emacs-lisp
(message "hello")
```

> Some quoted text.
>
> ```emacs-lisp
> (message "hello again")
> ```

Some other text.
